@@ -1,10 +1,5 @@
 #!/usr/bin/env python
 
-"""
-Open Issues
-	@bug Buttons are too small
-"""
-
 
 import gobject
 import gtk
@@ -364,8 +359,9 @@ def _fremantle_hildonize_scrollwindow(scrolledWindow):
 	pannableWindow.add(child)
 
 	parent = scrolledWindow.get_parent()
-	parent.remove(scrolledWindow)
-	parent.add(pannableWindow)
+	if parent is not None:
+		parent.remove(scrolledWindow)
+		parent.add(pannableWindow)
 
 	return pannableWindow
 
